@@ -6,7 +6,7 @@ use Test::Builder;
 use Sub::Uplevel qw( uplevel );
 use base qw( Exporter );
 
-our $VERSION = '0.35';
+our $VERSION = '0.37';
 our @EXPORT = qw(dies_ok lives_ok throws_ok lives_and);
 
 my $Tester = Test::Builder->new;
@@ -198,7 +198,7 @@ A true value is returned if the test succeeds, false otherwise. On exit $@ is gu
 
 A description of the exception being checked is used if no optional test description is passed.
 
-NOTE: Rememeber when you C<die $string_without_a_trailing_newline> perl will 
+NOTE: Remember when you C<die $string_without_a_trailing_newline> perl will 
 automatically add the current script line number, input line number and a newline. This will
 form part of the string that throws_ok regular expressions match against.
 
@@ -332,7 +332,7 @@ The test description is optional, but recommended.
 
 =cut
 
-my $is_stream = eval { require Test::Stream; require Test::Stream::Event::Ok; 1 };
+my $is_stream = $INC{'Test/Stream.pm'};
 our $LIVES_AND_NAME;
 if ($is_stream) {
     Test::Stream->shared->munge(sub {
